#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PyQt4 import QtCore, QtGui


class MyGraphicsScene( QtGui.QGraphicsScene ):
	mousePressed = QtCore.Signal(int,int)
	def __init__(self, parent = None):
		QtGui.QGraphicsScene.__init__(self, parent)

	def mousePressEvent( self, eventGrSc ):
		p = eventGrSc.scenePos()
		self.mousePressed.emit( p.x(), p.y() )

		QtGui.QGraphicsScene.mousePressEvent( self, eventGrSc )

